View source: R/count_methods.R
| confint.countpower | R Documentation |
Extract the Monte Carlo confidence interval from count power results
## S3 method for class 'countpower'
confint(object, parm = NULL, level = 0.95, ...)
## S3 method for class 'countss'
confint(object, parm = NULL, level = 0.95, ...)
object |
An object returned by a count power calculation. |
parm |
Unused; included for compatibility with |
level |
Confidence level for the Monte Carlo interval. |
... |
Unused additional arguments. |
A named vector containing the lower and upper interval limits.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.