View source: R/simpower_methods.R
| plot.simpower | R Documentation |
Plot fixed-sample-size power results
## S3 method for class 'simpower'
plot(x, target_power = 0.8, display = "all", all = TRUE, endpoint = NULL, ...)
x |
An object returned by |
target_power |
Target power shown as a horizontal reference line. |
display |
Character vector of comparator panels to display. This argument is retained for compatibility with curve results. |
all |
Logical retained for compatibility with curve results. If
|
endpoint |
Endpoint names to display for curve results. By default,
|
... |
Unused additional arguments. |
A ggplot object showing estimated power and its Monte Carlo
confidence interval.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.