summary.simpower: Summarize fixed-sample-size power results

View source: R/simpower_methods.R

summary.simpowerR Documentation

Summarize fixed-sample-size power results

Description

Summarize fixed-sample-size power results

Usage

## S3 method for class 'simpower'
summary(object, ...)

Arguments

object

An object returned by simPower().

...

Unused additional arguments.

Value

A data frame containing the distribution, design, comparison, estimand, hypotheses, sample size, estimated power, and Monte Carlo confidence interval.


SimTOST documentation built on Oct. 9, 2026, 5:07 p.m.