Update a standalone count power calculation

# S3 method for class 'countpower'
update(object, ..., evaluate = TRUE)

Arguments

object

A standalone countpower object returned by a count power function.

...

Arguments to replace in the original calculation.

evaluate

If FALSE, return the updated call instead of evaluating it.

Value

A newly calculated count power object, or an unevaluated call.