Update a standalone count sample-size calculation

# S3 method for class 'countss'
update(object, ..., evaluate = TRUE)

Arguments

object

A standalone countss object returned by a count sample-size function.

...

Arguments to replace in the original calculation.

evaluate

If FALSE, return the updated call instead of evaluating it.

Value

A newly calculated count sample-size object, or an unevaluated call.