Update a SimTOST fixed-sample-size power calculation

# S3 method for class 'simpower'
update(object, ..., evaluate = TRUE)

Arguments

object

A simpower object, including unified count-outcome results.

...

Arguments to replace in the original calculation.

evaluate

If FALSE, return the updated call instead of evaluating it.

Value

A newly calculated simpower object, or an unevaluated call.