Re-runs the calculation represented by object, replacing only arguments supplied in .... This is useful for changing, for example, the target power or number of simulations without repeating the complete original call.

# S3 method for class 'simss'
update(object, ..., evaluate = TRUE)

Arguments

object

A simss object, including count-outcome sample-size objects.

...

Arguments to replace in the original calculation.

evaluate

If FALSE, return the updated call instead of evaluating it.

Value

A newly calculated object of the same result family as object, or an unevaluated call when evaluate = FALSE.