confint.countpower.RdExtract the Monte Carlo confidence interval from count power results
An object returned by a count power calculation.
Unused; included for compatibility with stats::confint().
Confidence level for the Monte Carlo interval.
Unused additional arguments.
A named vector containing the lower and upper interval limits.