| .select_power_plot_n | R Documentation |
The sample-size search may evaluate candidates in a non-monotone order. Plot selection must therefore be based on the plotted global total-power rows, not on the order in which the optimizer evaluated candidates.
.select_power_plot_n(data, target_power, n_col, fallback = NA_real_)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.