Plot fixed-sample-size power results

# S3 method for class 'simpower'
plot(x, target_power = 0.8, display = "all", all = TRUE, endpoint = NULL, ...)

Arguments

x

An object returned by simPower().

target_power

Target power shown as a horizontal reference line.

display

Character vector of comparator panels to display. This argument is retained for compatibility with curve results.

all

Logical retained for compatibility with curve results. If TRUE, the aggregate result is displayed when available.

endpoint

Endpoint names to display for curve results. By default, "Total" is used when all = TRUE, while all retained endpoints are used when all = FALSE. Use "all" to show all retained endpoints.

...

Unused additional arguments.

Value

A ggplot object showing estimated power and its Monte Carlo confidence interval.