plot.simpower.RdPlot fixed-sample-size power results
# S3 method for class 'simpower'
plot(x, target_power = 0.8, display = "all", all = TRUE, endpoint = NULL, ...)An object returned by simPower().
Target power shown as a horizontal reference line.
Character vector of comparator panels to display. This argument is retained for compatibility with curve results.
Logical retained for compatibility with curve results. If
TRUE, the aggregate result is displayed when available.
Endpoint names to display for curve results. By default,
"Total" is used when all = TRUE, while all retained endpoints are
used when all = FALSE. Use "all" to show all retained endpoints.
Unused additional arguments.
A ggplot object showing estimated power and its Monte Carlo
confidence interval.