The plot displays the complete-trial Type I error at all evaluated boundaries. The worst-case scenario is highlighted with a thicker interval and a larger point, and its estimated value is shown next to the point. Error bars are 95% Monte Carlo confidence intervals.

# S3 method for class 'type1error'
plot(x, ...)

Arguments

x

An object returned by type1Error().

...

Unused additional arguments.

Value

A ggplot object.