Displays the 95\ of simulated trials increases. Decreasing curves indicate improving precision; a curve that has not flattened may require a larger nsim.

plot_mc_error(x, display = "all", overall = FALSE, ...)

Arguments

x

A simss, simpower, or simpower_curve object, or a list of such objects. A list can compare simulations with different n and nsim values.

display

Comparator names to display, or "all".

overall

Logical. If TRUE, display only the All comparators aggregate result. This is useful for assessing the overall decision when several comparisons are required; display is ignored in this mode.

...

Unused additional arguments.

Value

A ggplot object.