Prints the same design-oriented sample-size report used for continuous outcomes. Count-specific result fields and search histories are retained in the object, while the invisible return value is a data frame of the selected per-arm (or per-sequence) and total sample sizes.

# S3 method for class 'countss'
summary(object, ...)

Arguments

object

A countss object returned by a count sample-size calculation or by the unified sampleSize() function.

...

Unused additional arguments.

Value

Invisibly, a data frame containing the selected sample size for each arm (or sequence) and the total sample size.