View source: R/simpower_methods.R
| summary.simpower | R Documentation |
Summarize fixed-sample-size power results
## S3 method for class 'simpower'
summary(object, ...)
object |
An object returned by |
... |
Unused additional arguments. |
A data frame containing the distribution, design, comparison, estimand, hypotheses, sample size, estimated power, and Monte Carlo confidence interval.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.