Summarize fixed-sample-size power results

# S3 method for class 'simpower'
summary(object, ...)

Arguments

object

An object returned by simPower().

...

Unused additional arguments.

Value

A data frame containing the distribution, design, comparison, estimand, hypotheses, sample size, estimated power, and Monte Carlo confidence interval.