update.countpower.Rd
Update a standalone count power calculation
# S3 method for class 'countpower' update(object, ..., evaluate = TRUE)
A standalone countpower object returned by a count power function.
countpower
Arguments to replace in the original calculation.
If FALSE, return the updated call instead of evaluating it.
FALSE
A newly calculated count power object, or an unevaluated call.