update.countss.Rd
Update a standalone count sample-size calculation
# S3 method for class 'countss' update(object, ..., evaluate = TRUE)
A standalone countss object returned by a count sample-size function.
countss
Arguments to replace in the original calculation.
If FALSE, return the updated call instead of evaluating it.
FALSE
A newly calculated count sample-size object, or an unevaluated call.