update.simpower.Rd
Update a SimTOST fixed-sample-size power calculation
# S3 method for class 'simpower' update(object, ..., evaluate = TRUE)
A simpower object, including unified count-outcome results.
simpower
Arguments to replace in the original calculation.
If FALSE, return the updated call instead of evaluating it.
FALSE
A newly calculated simpower object, or an unevaluated call.